/*-
 * Copyright (c) 2010 Hans Petter Selasky. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef _VIDEO4BSD_H_
#define	_VIDEO4BSD_H_

#include <sys/ioccom.h>

#define	V4B_BUFFER_MAX		0x4000	/* 16Kbyte */
#define	V4B_DEVICES_MAX		10	/* units */
#define	V4B_BUF_MIN_PTR		((uint8_t *)0x10000UL)
#define	V4B_BUF_MAX_PTR		((uint8_t *)0x20000UL)
#define	V4B_ALLOC_UNIT_MAX	16	/* units */
#define	V4B_ALLOC_PAGES_MAX	(((64UL * 1024UL * 1024UL) + PAGE_SIZE - 1) / PAGE_SIZE)

enum {
	V4B_CMD_NONE,
	V4B_CMD_OPEN,
	V4B_CMD_CLOSE,
	V4B_CMD_READ,
	V4B_CMD_WRITE,
	V4B_CMD_IOCTL,
	V4B_CMD_MMAP,
	V4B_CMD_SYNC,
	V4B_CMD_MAX,
};

struct v4b_data_chunk {
	uint8_t *client_ptr;
	uint8_t *peer_ptr;
	uint32_t length;
};

struct v4b_mem_alloc {
	uint32_t page_count;
	uint8_t	alloc_nr;
};

struct v4b_command {
	void   *ptr;
	uint32_t arg;
	uint8_t	command;		/* see V4B_CMD_XXX */
};

#define	V4B_IOCTL_WRITE_DATA		_IOWR('V', 0, struct v4b_data_chunk)
#define	V4B_IOCTL_READ_DATA		_IOWR('V', 1, struct v4b_data_chunk)
#define	V4B_IOCTL_GET_COMMAND		 _IOR('V', 2, struct v4b_command)
#define	V4B_IOCTL_SYNC_COMMAND		 _IOW('V', 3, int)
#define	V4B_IOCTL_ALLOC_MEMORY		 _IOW('V', 4, struct v4b_mem_alloc)
#define	V4B_IOCTL_FREE_MEMORY		 _IOW('V', 5, struct v4b_mem_alloc)
#define	V4B_IOCTL_MAP_MEMORY		 _IOW('V', 6, struct v4b_mem_alloc)

#endif					/* _VIDEO4BSD_H_ */
